State

Trait State 

pub trait State:
    Eq
    + Debug
    + Default
    + Display
    + Clone { }
The State trait represents the type of states that can be used in the conditions. It must implement Eq, Hash, Debug, Default, Display, and Clone.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors