pub trait Value:
Eq
+ Hash
+ Debug
+ Default
+ Display
+ Clone { }Expand description
The Value trait represents the type of values that can be used in the conditions. It must implement Eq, Hash, Debug, Default, Display, and Clone.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.